#! /usr/bin/env bash
# This file contains the complete sequence of commands
# CodeSourcery used to build this version of Sourcery G++.
# 
# For each free or open-source component of Sourcery G++, the
# source code provided includes all of the configuration
# scripts and makefiles for that component, including any and
# all modifications made by CodeSourcery.  From this list of
# commands, you can see every configuration option used by
# CodeSourcery during the build process.
# 
# This file is provided as a guideline for users who wish to
# modify and rebuild a free or open-source component of
# Sourcery G++ from source. For a number of reasons, though,
# you may not be able to successfully run this script directly
# on your system. Certain aspects of the CodeSourcery build
# environment (such as directory names) are included in these
# commands. CodeSourcery uses Canadian cross compilers so you
# may need to modify various configuration options and paths
# if you are building natively. This sequence of commands
# includes those used to build proprietary components of
# Sourcery G++ for which source code is not provided.
# 
# Please note that Sourcery G++ support covers only your use
# of the original, validated binaries provided as part of
# Sourcery G++ -- and specifically does not cover either the
# process of rebuilding a component or the use of any binaries
# you may build.  In addition, if you rebuild any component,
# you must not use the --with-pkgversion and --with-bugurl
# configuration options that embed CodeSourcery trademarks in
# the resulting binary; see the "CodeSourcery Trademarks"
# section in the Sourcery G++ Software License Agreement.
set -e
inform_fd=2 
umask 022
exec < /dev/null

error_handler ()
{
    exit 1
}

check_status() {
    local status="$?"
    if [ "$status" -ne 0 ]; then
	error_handler
    fi
}

check_pipe() {
    local -a status=("${PIPESTATUS[@]}")
    local limit=$1
    local ix
    
    if [ -z "$limit" ] ; then
	limit="${#status[@]}"
    fi
    for ((ix=0; ix != $limit ; ix++)); do
	if [ "${status[$ix]}" != "0" ] ; then
	    error_handler
	fi
    done
}

error () {
    echo "$script: error: $@" >& $inform_fd
    exit 1
}

warning () {
    echo "$script: warning: $@" >& $inform_fd
}

verbose () {
    if $gnu_verbose; then
	echo "$script: $@" >& $inform_fd
    fi
}

copy_dir() {
    mkdir -p "$2"

    (cd "$1" && tar cf - .) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_clean() {
    mkdir -p "$2"
    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	.) | (cd "$2" && tar xf -)
    check_pipe
}

update_dir_clean() {
    mkdir -p "$2"


    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	--after-date="$3" \
	. 2> /dev/null) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_exclude() {
    local source="$1"
    local dest="$2"
    local excl="$3"
    shift 3
    mkdir -p "$dest"
    (cd "$source" && tar cfX - "$excl" "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

copy_dir_only() {
    local source="$1"
    local dest="$2"
    shift 2
    mkdir -p "$dest"
    (cd "$source" && tar cf - "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

clean_environment() {
    local env_var_list
    local var




    unset BASH_ENV CDPATH POSIXLY_CORRECT TMOUT

    env_var_list=$(export | \
	grep '^declare -x ' | \
	sed -e 's/^declare -x //' -e 's/=.*//')

    for var in $env_var_list; do
	case $var in
	    HOME|HOSTNAME|LOGNAME|PWD|SHELL|SHLVL|SSH_*|TERM|USER)


		;;
	    LD_LIBRARY_PATH|PATH| \
		FLEXLM_NO_CKOUT_INSTALL_LIC|LM_APP_DISABLE_CACHE_READ)


		;;
	    MAKEINFO)

		;;
	    *_LICENSE_FILE)












		if [ "" ]; then
		    local license_file_envvar
		    license_file_envvar=

		    if [ "$var" != "$license_file_envvar" ]; then
			export -n "$var" || true
		    fi
		else
		    export -n "$var" || true
		fi
		;;
	    *)

		export -n "$var" || true
		;;
	esac
    done


    export LANG=C
    export LC_ALL=C


    export CVS_RSH=ssh



    user_shell=$SHELL
    export SHELL=$BASH
    export CONFIG_SHELL=$BASH
}

pushenv() {
    pushenv_level=$(($pushenv_level + 1))
    eval pushenv_vars_${pushenv_level}=
}


pushenv_level=0
pushenv_vars_0=



pushenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    eval local pushenv_oldset=\"\${$pushenv_var+set}\"
    local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
    local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
    eval local pushenv_save_set=\"\${$pushenv_savep_var+set}\"
    if [ "$pushenv_save_set" = "set" ]; then
	error "Pushing $pushenv_var more than once at level $pushenv_level"
    fi
    if [ "$pushenv_oldset" = "set" ]; then
	eval $pushenv_save_var=\"\$pushenv_oldval\"
    else
	unset $pushenv_save_var
    fi
    eval $pushenv_savep_var=1
    eval export $pushenv_var=\"\$pushenv_newval\"
    local pushenv_list_var=pushenv_vars_${pushenv_level}
    eval $pushenv_list_var=\"\$$pushenv_list_var \$pushenv_var\"
}

prependenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    pushenvvar "$pushenv_var" "$pushenv_newval$pushenv_oldval"
}

popenv() {
    local pushenv_var=
    eval local pushenv_vars=\"\$pushenv_vars_${pushenv_level}\"
    for pushenv_var in $pushenv_vars; do
	local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
	local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
	eval local pushenv_save_val=\"\$$pushenv_save_var\"
	eval local pushenv_save_set=\"\${$pushenv_save_var+set}\"
	unset $pushenv_save_var
	unset $pushenv_savep_var
	if [ "$pushenv_save_set" = "set" ]; then
	    eval export $pushenv_var=\"\$pushenv_save_val\"
	else
	    unset $pushenv_var
	fi
    done
    unset pushenv_vars_${pushenv_level}
    if [ "$pushenv_level" = "0" ]; then
	error "Popping environment level 0"
    else
	pushenv_level=$(($pushenv_level - 1))
    fi
}

prepend_path() {
    if $(eval "test -n \"\$$1\""); then
	prependenvvar "$1" "$2:"
    else
	prependenvvar "$1" "$2"
    fi
}
pushenvvar CSL_SCRIPTDIR /scratch/macro/mips-sde-4.2/src/scripts-trunk
pushenvvar PATH /usr/local/tools/gcc-3.4.0/bin:/bin:/usr/bin
pushenvvar LD_LIBRARY_PATH /usr/local/tools/gcc-3.4.0/lib64:/usr/local/tools/gcc-3.4.0/lib
pushenvvar MAKEINFO '/usr/local/tools/gcc-3.4.0/texinfo-4.12/bin/makeinfo --css-ref=../cs.css'
clean_environment
# task [001/158] /init/dirs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/macro/mips-sde-4.2/obj
mkdir -p /scratch/macro/mips-sde-4.2/install
mkdir -p /scratch/macro/mips-sde-4.2/pkg
mkdir -p /scratch/macro/mips-sde-4.2/logs/data
mkdir -p /scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/html
mkdir -p /scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/pdf
popenv

# task [002/158] /init/cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf.src.tar.bz2 /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf.backup.tar.bz2
popenv

# task [003/158] /init/source_package/binutils
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/binutils-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/binutils-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' binutils-mips
popd
popenv

# task [004/158] /init/source_package/gcc
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/gcc-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/gcc-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gcc-4.2
popd
popenv

# task [005/158] /init/source_package/gdb
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/gdb-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/gdb-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gdb-mips
popd
popenv

# task [006/158] /init/source_package/getting_started
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/getting_started-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/getting_started-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' getting-started-stable
popd
popenv

# task [007/158] /init/source_package/installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/installanywhere-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/installanywhere-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' installanywhere-stable
popd
popenv

# task [008/158] /init/source_package/ph
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/ph-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/ph-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' ph-stable
popd
popenv

# task [009/158] /init/source_package/eembc
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/eembc-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/eembc-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' eembc-trunk
popd
popenv

# task [010/158] /init/source_package/dhrystone
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/dhrystone-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/dhrystone-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' dhrystone-trunk
popd
popenv

# task [011/158] /init/source_package/sde
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/sde-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/sde-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' sde-trunk
popd
popenv

# task [012/158] /init/source_package/sdemdi
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/sdemdi-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/sdemdi-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' sdemdi-trunk
popd
popenv

# task [013/158] /init/source_package/csl_tests
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/csl_tests-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/csl_tests-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-tests-trunk
popd
popenv

# task [014/158] /init/source_package/dejagnu_boards
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/dejagnu_boards-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/dejagnu_boards-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' dejagnu-boards-trunk
popd
popenv

# task [015/158] /init/source_package/scripts
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/scripts-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/scripts-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' scripts-trunk
popd
popenv

# task [016/158] /init/source_package/xfails
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/xfails-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/xfails-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' xfails-trunk
popd
popenv

# task [017/158] /init/source_package/portal
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/portal-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/portal-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' portal-trunk
popd
popenv

# task [018/158] /init/source_package/libiconv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/libiconv-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/libiconv-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' libiconv-1.11
popd
popenv

# task [019/158] /init/source_package/expat
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/expat-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/expat-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' expat-mirror
popd
popenv

# task [020/158] /init/source_package/csl_docbook
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/csl_docbook-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/csl_docbook-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-docbook-stable
popd
popenv

# task [021/158] /init/source_package/make
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/make-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/make-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' make-3.81
popd
popenv

# task [022/158] /init/source_package/coreutils
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/coreutils-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf/coreutils-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' coreutils-5.94
popd
popenv

# task [023/158] /init/source_package/qmtest_ph
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/qmtest_ph-4.2-199.tar.bz2
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/src
tar cf /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup/qmtest_ph-4.2-199.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' qmtest_ph-stable
popd
popenv

# task [024/158] /i686-pc-linux-gnu/host_cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
popenv

# task [025/158] /i686-pc-linux-gnu/toolchain/binutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu
copy_dir_clean /scratch/macro/mips-sde-4.2/src/binutils-mips /scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu
touch /scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu/.gnu-stamp
popenv
popenv
popenv

# task [026/158] /i686-pc-linux-gnu/toolchain/binutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu
mkdir -p /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu
pushd /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu
/scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/opt/codesourcery --host=i686-pc-linux-gnu '--with-pkgversion=Sourcery G++ Lite 4.2-199' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --with-sysroot=/opt/codesourcery/mips-sde-elf --enable-poison-system-directories
popd
popenv
popenv
popenv

# task [027/158] /i686-pc-linux-gnu/toolchain/binutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [028/158] /i686-pc-linux-gnu/toolchain/binutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make install prefix=/scratch/macro/mips-sde-4.2/install exec_prefix=/scratch/macro/mips-sde-4.2/install libdir=/scratch/macro/mips-sde-4.2/install/lib htmldir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/man datadir=/scratch/macro/mips-sde-4.2/install/share
popd
popenv
popenv
popenv

# task [029/158] /i686-pc-linux-gnu/toolchain/binutils/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/install
rm ./lib/libiberty.a
rmdir ./lib
popd
copy_dir_clean /scratch/macro/mips-sde-4.2/src/binutils-mips/include /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr/include
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr/include
mkdir -p /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr/lib
cp /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/libiberty/libiberty.a /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr/lib
cp /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/bfd/.libs/libbfd.a /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr/lib
cp /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/bfd/bfd.h /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr/include
cp /scratch/macro/mips-sde-4.2/src/binutils-mips/bfd/elf-bfd.h /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr/include
cp /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/opcodes/.libs/libopcodes.a /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr/lib
popenv
popenv
popenv

# task [030/158] /i686-pc-linux-gnu/toolchain/sde/install_headers
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar SDEPREFIX mips-sde-elf-
rm -rf /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
pushd /scratch/macro/mips-sde-4.2/src/sde-trunk/include
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 _G_config.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 alloca.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 ar.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 assert.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 conc.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 ctype.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 def.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 dirent.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 err.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 errno.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 fcntl.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 fenv.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 float.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 getopt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 grp.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 ieee754.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 ifaddrs.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 inttypes.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 iso646.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 libc_thread.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 limits.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 locale.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 math.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 mqueue.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 netdb.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 netgroup.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 paths.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 pthread.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 pwd.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 resolv.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 sched.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 sdethread.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 semaphore.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 setjmp.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 sgidefs.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 signal.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 stdarg.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 stddef.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 stdint.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 stdio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 stdlib.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 string.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 syslog.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 termios.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 time.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 unaligned.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 unistd.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 utime.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 values.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 varargs.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
install -m 644 wchar.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
popd
pushd /scratch/macro/mips-sde-4.2/src/sde-trunk/include/arpa
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/arpa
install -m 644 ftp.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/arpa
install -m 644 inet.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/arpa
install -m 644 nameser.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/arpa
install -m 644 telnet.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/arpa
install -m 644 tftp.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/arpa
popd
pushd /scratch/macro/mips-sde-4.2/src/sde-trunk/include/idt
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/idt
install -m 644 idtsim.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/idt
install -m 644 r3041.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/idt
install -m 644 r3081.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/idt
install -m 644 r36100.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/idt
install -m 644 r3710.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/idt
install -m 644 rc3233x.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/idt
install -m 644 rc32364.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/idt
install -m 644 rc6457x.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/idt
popd
pushd /scratch/macro/mips-sde-4.2/src/sde-trunk/include/lsi
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 cw10tlb.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 cw4002.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 cw400x.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 cw401x.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 cwxcpt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 l64360.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 lr33000.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 lr33020.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 lr33300.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 pmon.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 termio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 tr4101.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
install -m 644 tr4102.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/lsi
popd
pushd /scratch/macro/mips-sde-4.2/src/sde-trunk/include/mips
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 amethyst.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 ansi.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 asm.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 atomic.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 bt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 cdefs.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 cop2.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 cpu.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 dsp.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 endian.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 fenv.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 fenvinline.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 fgregdef.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 float.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 fpa.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 ieee754.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 instr16def.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 instrdef.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 int_const.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 int_fmtio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 int_limits.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 int_mwgwtypes.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 int_types.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 jade.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 limits.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 m16c0.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 m16c1.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 m32c0.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 m32c1.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 m32tlb.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 m32xcpt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 m64c0.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 mips24k.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 mips32.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 mips34k.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 mips4ks.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 mips64.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 mips74k.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 mt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 notlb.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 nuxi.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 opal.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 prid.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r3kc0.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r3kc1.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r3ktlb.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r3kxcpt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r4650.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r4650xcpt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r4kc0.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r4kc1.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r4ktlb.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r4kxcpt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r5kc0.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r5kc1.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 r5kxcpt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 regdef.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 rm7kc0.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 rm7kxcpt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 rtlx.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 ruby.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 smartmips.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 stdarg.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 types.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 udi.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 values.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 watchpoint.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 xcpt.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
install -m 644 xcptcpu.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/mips
popd
pushd /scratch/macro/mips-sde-4.2/src/sde-trunk/include/nec
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/nec
install -m 644 vr41xxio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/nec
popd
pushd /scratch/macro/mips-sde-4.2/src/sde-trunk/include/pci
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pci
install -m 644 device.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pci
install -m 644 pcidevs.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pci
install -m 644 pcireg.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pci
install -m 644 pcivar.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pci
popd
pushd /scratch/macro/mips-sde-4.2/src/sde-trunk/include/pthread
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pthread
install -m 644 impl.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pthread
install -m 644 limits.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pthread
install -m 644 rtpxint.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pthread
install -m 644 unistd.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/pthread
popd
pushd /scratch/macro/mips-sde-4.2/src/sde-trunk/include/sys
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 cdefs.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 clock.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 dirent.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 dkio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 elf.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 elfmips.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 endian.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 errno.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 fcntl.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 filedesc.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 filio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 flashio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 init.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 ioccom.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 ioctl.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 limits.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 mtspio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 panelio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 param.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 posix.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 proc.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 queue.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 resource.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 sdeversion.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 select.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 signal.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 sockio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 stat.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 swap.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 sysctl.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 syslimits.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 termios.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 time.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 times.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 ttycom.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 ttydefaults.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 types.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 uio.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 unistd.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 utsname.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
install -m 644 wait.h /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include/sys
popd
pushd /scratch/macro/mips-sde-4.2/install/mips-sde-elf/include
ln -s mips machine
popd
popenv
popenv

# task [031/158] /i686-pc-linux-gnu/toolchain/gcc_first/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
rm -rf /scratch/macro/mips-sde-4.2/obj/gcc-first-4.2-199-mips-sde-elf-i686-pc-linux-gnu
mkdir -p /scratch/macro/mips-sde-4.2/obj/gcc-first-4.2-199-mips-sde-elf-i686-pc-linux-gnu
pushd /scratch/macro/mips-sde-4.2/obj/gcc-first-4.2-199-mips-sde-elf-i686-pc-linux-gnu
/scratch/macro/mips-sde-4.2/src/gcc-4.2/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=mips-sde-elf --enable-threads --disable-libmudflap --disable-libssp --disable-libstdcxx-pch --with-arch=mips32r2 --enable-sgxx-sde-multilibs --with-gnu-as --with-gnu-ld --enable-languages=c,c++ --disable-shared --disable-lto '--with-pkgversion=Sourcery G++ Lite 4.2-199' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --prefix=/opt/codesourcery --disable-shared --disable-threads --disable-libssp --disable-libgomp --without-headers --without-newlib --disable-decimal-float --disable-libffi --enable-languages=c --with-sysroot=/opt/codesourcery/mips-sde-elf --with-build-sysroot=/scratch/macro/mips-sde-4.2/install/mips-sde-elf --disable-libgomp --enable-poison-system-directories --with-build-time-tools=/scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin --with-build-time-tools=/scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin
popd
popenv
popenv

# task [032/158] /i686-pc-linux-gnu/toolchain/gcc_first/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
pushd /scratch/macro/mips-sde-4.2/obj/gcc-first-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make -j4 LDFLAGS_FOR_TARGET=--sysroot=/scratch/macro/mips-sde-4.2/install/mips-sde-elf CPPFLAGS_FOR_TARGET=--sysroot=/scratch/macro/mips-sde-4.2/install/mips-sde-elf build_tooldir=/scratch/macro/mips-sde-4.2/install/mips-sde-elf
popd
popenv
popenv

# task [033/158] /i686-pc-linux-gnu/toolchain/gcc_first/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
pushd /scratch/macro/mips-sde-4.2/obj/gcc-first-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make prefix=/scratch/macro/mips-sde-4.2/install exec_prefix=/scratch/macro/mips-sde-4.2/install libdir=/scratch/macro/mips-sde-4.2/install/lib htmldir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/man install
popd
popenv
popenv

# task [034/158] /i686-pc-linux-gnu/toolchain/gcc_first/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
pushd /scratch/macro/mips-sde-4.2/install
rm bin/mips-sde-elf-gccbug
rm ./lib/libiberty.a
rmdir include
popd
popenv
popenv

# task [035/158] /i686-pc-linux-gnu/toolchain/sde/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar SDEPREFIX mips-sde-elf-
rm -rf /scratch/macro/mips-sde-4.2/obj/sde-4.2-199-mips-sde-elf-i686-pc-linux-gnu
copy_dir_clean /scratch/macro/mips-sde-4.2/src/sde-trunk /scratch/macro/mips-sde-4.2/obj/sde-4.2-199-mips-sde-elf-i686-pc-linux-gnu
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/sde-4.2-199-mips-sde-elf-i686-pc-linux-gnu
popenv
popenv

# task [036/158] /i686-pc-linux-gnu/toolchain/sde/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar SDEPREFIX mips-sde-elf-
pushd /scratch/macro/mips-sde-4.2/obj/sde-4.2-199-mips-sde-elf-i686-pc-linux-gnu/include
ln -s mips machine
popd
popenv
popenv

# task [037/158] /i686-pc-linux-gnu/toolchain/sde/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar SDEPREFIX mips-sde-elf-
pushd /scratch/macro/mips-sde-4.2/obj/sde-4.2-199-mips-sde-elf-i686-pc-linux-gnu/lib
make
popd
popenv
popenv

# task [038/158] /i686-pc-linux-gnu/toolchain/sde/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar SDEPREFIX mips-sde-elf-
pushd /scratch/macro/mips-sde-4.2/obj/sde-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make DESTDIR=/scratch/macro/mips-sde-4.2/install/mips-sde-elf/ install
popd
mkdir -p share/doc/mips-mips-sde-elf/pdf
cp /scratch/macro/mips-sde-4.2/src/sde-trunk/doc/MIPS-SDE-LIBRARY.pdf /scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/pdf
cp /scratch/macro/mips-sde-4.2/src/sde-trunk/doc/MIPS-TOOLCHAIN.pdf /scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/pdf
popenv
popenv

# task [039/158] /i686-pc-linux-gnu/toolchain/gcc_final/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
rm -f /scratch/macro/mips-sde-4.2/install/mips-sde-elf/usr
ln -s . /scratch/macro/mips-sde-4.2/install/mips-sde-elf/usr
rm -rf /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-pc-linux-gnu
mkdir -p /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-pc-linux-gnu
pushd /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-pc-linux-gnu
/scratch/macro/mips-sde-4.2/src/gcc-4.2/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=mips-sde-elf --enable-threads --disable-libmudflap --disable-libssp --disable-libstdcxx-pch --with-arch=mips32r2 --enable-sgxx-sde-multilibs --with-gnu-as --with-gnu-ld --enable-languages=c,c++ --disable-shared --disable-lto '--with-pkgversion=Sourcery G++ Lite 4.2-199' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --prefix=/opt/codesourcery --with-headers=yes --with-sysroot=/opt/codesourcery/mips-sde-elf --with-build-sysroot=/scratch/macro/mips-sde-4.2/install/mips-sde-elf --disable-libgomp --enable-poison-system-directories --with-build-time-tools=/scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin --with-build-time-tools=/scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin
popd
popenv
popenv

# task [040/158] /i686-pc-linux-gnu/toolchain/gcc_final/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
rm -f /scratch/macro/mips-sde-4.2/install/mips-sde-elf/usr
ln -s . /scratch/macro/mips-sde-4.2/install/mips-sde-elf/usr
pushd /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make -j4 LDFLAGS_FOR_TARGET=--sysroot=/scratch/macro/mips-sde-4.2/install/mips-sde-elf CPPFLAGS_FOR_TARGET=--sysroot=/scratch/macro/mips-sde-4.2/install/mips-sde-elf build_tooldir=/scratch/macro/mips-sde-4.2/install/mips-sde-elf
popd
popenv
popenv

# task [041/158] /i686-pc-linux-gnu/toolchain/gcc_final/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
rm -f /scratch/macro/mips-sde-4.2/install/mips-sde-elf/usr
ln -s . /scratch/macro/mips-sde-4.2/install/mips-sde-elf/usr
pushd /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make prefix=/scratch/macro/mips-sde-4.2/install exec_prefix=/scratch/macro/mips-sde-4.2/install libdir=/scratch/macro/mips-sde-4.2/install/lib htmldir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/man install
popd
popenv
popenv

# task [042/158] /i686-pc-linux-gnu/toolchain/gcc_final/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
pushd /scratch/macro/mips-sde-4.2/install
rm bin/mips-sde-elf-gccbug
rm ./lib/libiberty.a
rmdir include
popd
rm -f /scratch/macro/mips-sde-4.2/install/mips-sde-elf/usr
popenv
popenv

# task [043/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/default/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/default/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/default/
pushenv
pushenvvar CC 'mips-sde-elf-gcc '
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [044/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/default/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/./
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/./
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/./
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/./
popd
popenv

# task [045/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_1/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [046/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_1/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/
popd
popenv

# task [047/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_2/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mips16'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [048/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_2/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/
popd
popenv

# task [049/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_3/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mfp64/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mfp64/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mfp64/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mfp64'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [050/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_3/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mfp64/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/
popd
popenv

# task [051/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_4/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/msoft-float/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/msoft-float/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/msoft-float/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -msoft-float'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [052/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_4/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/msoft-float/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/
popd
popenv

# task [053/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_5/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mno-float/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mno-float/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mno-float/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mno-float'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [054/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_5/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mno-float/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/
popd
popenv

# task [055/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_6/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mfp64/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mfp64/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mfp64/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mips16 -mfp64'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [056/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_6/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mfp64/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/
popd
popenv

# task [057/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_7/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-msoft-float/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-msoft-float/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-msoft-float/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mips16 -msoft-float'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [058/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_7/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-msoft-float/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/
popd
popenv

# task [059/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_8/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mno-float/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mno-float/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mno-float/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mips16 -mno-float'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [060/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_8/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mno-float/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/
popd
popenv

# task [061/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_9/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mcode-readable_no/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mcode-readable_no/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mcode-readable_no/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mips16 -mcode-readable=no'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [062/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_9/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mcode-readable_no/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/
popd
popenv

# task [063/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_10/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mfp64-mcode-readable_no/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mfp64-mcode-readable_no/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mfp64-mcode-readable_no/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mips16 -mfp64 -mcode-readable=no'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [064/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_10/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mfp64-mcode-readable_no/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/
popd
popenv

# task [065/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_11/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-msoft-float-mcode-readable_no/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-msoft-float-mcode-readable_no/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-msoft-float-mcode-readable_no/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mips16 -msoft-float -mcode-readable=no'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [066/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_11/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-msoft-float-mcode-readable_no/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/
popd
popenv

# task [067/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_12/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mno-float-mcode-readable_no/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mno-float-mcode-readable_no/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mno-float-mcode-readable_no/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -mips16 -mno-float -mcode-readable=no'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [068/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_12/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/mips16-mno-float-mcode-readable_no/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/
popd
popenv

# task [069/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_13/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mips16'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [070/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_13/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/
popd
popenv

# task [071/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_14/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mfp64/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mfp64/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mfp64/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mfp64'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [072/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_14/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mfp64/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/
popd
popenv

# task [073/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_15/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-msoft-float/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-msoft-float/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-msoft-float/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -msoft-float'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [074/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_15/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-msoft-float/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/
popd
popenv

# task [075/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_16/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mno-float/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mno-float/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mno-float/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mno-float'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [076/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_16/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mno-float/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/
popd
popenv

# task [077/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_17/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mfp64/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mfp64/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mfp64/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mips16 -mfp64'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [078/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_17/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mfp64/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/
popd
popenv

# task [079/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_18/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-msoft-float/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-msoft-float/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-msoft-float/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mips16 -msoft-float'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [080/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_18/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-msoft-float/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/
popd
popenv

# task [081/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_19/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mno-float/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mno-float/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mno-float/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mips16 -mno-float'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [082/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_19/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mno-float/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/
popd
popenv

# task [083/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_20/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mcode-readable_no/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mcode-readable_no/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mcode-readable_no/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mips16 -mcode-readable=no'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [084/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_20/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mcode-readable_no/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/
popd
popenv

# task [085/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_21/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mfp64-mcode-readable_no/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mfp64-mcode-readable_no/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mfp64-mcode-readable_no/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mips16 -mfp64 -mcode-readable=no'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [086/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_21/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mfp64-mcode-readable_no/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/
popd
popenv

# task [087/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_22/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-msoft-float-mcode-readable_no/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-msoft-float-mcode-readable_no/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-msoft-float-mcode-readable_no/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mips16 -msoft-float -mcode-readable=no'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [088/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_22/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-msoft-float-mcode-readable_no/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/
popd
popenv

# task [089/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_23/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mno-float-mcode-readable_no/
mkdir -p /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mno-float-mcode-readable_no/
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mno-float-mcode-readable_no/
pushenv
pushenvvar CC 'mips-sde-elf-gcc -EL -mips16 -mno-float -mcode-readable=no'
/scratch/macro/mips-sde-4.2/src/sdemdi-trunk/sdemdi/configure --build=i686-pc-linux-gnu --host=mips-sde-elf
popenv
pushenv
pushenvvar CSL_CFLAGS -mno-gpopt
make -j4
popenv
popd
popenv

# task [090/158] /i686-pc-linux-gnu/toolchain/sdemdi/other_23/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/obj/sdemdi-4.2-199-mips-sde-elf-i686-pc-linux-gnu/EL-mips16-mno-float-mcode-readable_no/
install -d /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/
install -m 644 libmdi.a /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/
install -m 644 crt0.o /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/
install -m 644 sdemdi32.ld sdemdi32hi.ld sdemdi64.ld sdemdi64hi.ld /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/
popd
popenv

# task [091/158] /i686-pc-linux-gnu/toolchain/expat/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-pc-linux-gnu
mkdir -p /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-pc-linux-gnu
pushd /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-pc-linux-gnu
/scratch/macro/mips-sde-4.2/src/expat-mirror/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/scratch/macro/mips-sde-4.2/obj/host-libs-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr --disable-shared --host=i686-pc-linux-gnu --disable-nls
popd
popenv
popenv
popenv

# task [092/158] /i686-pc-linux-gnu/toolchain/expat/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [093/158] /i686-pc-linux-gnu/toolchain/expat/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make install
popd
popenv
popenv
popenv

# task [094/158] /i686-pc-linux-gnu/toolchain/gdb/0/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu
copy_dir_clean /scratch/macro/mips-sde-4.2/src/gdb-mips /scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu
touch /scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu/.gnu-stamp
popenv
popenv
popenv

# task [095/158] /i686-pc-linux-gnu/toolchain/gdb/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-pc-linux-gnu
mkdir -p /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-pc-linux-gnu
pushd /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-pc-linux-gnu
/scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/opt/codesourcery --host=i686-pc-linux-gnu '--with-pkgversion=Sourcery G++ Lite 4.2-199' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --with-libexpat-prefix=/scratch/macro/mips-sde-4.2/obj/host-libs-4.2-199-mips-sde-elf-i686-pc-linux-gnu/usr --with-system-gdbinit=/opt/codesourcery/i686-pc-linux-gnu/mips-sde-elf/lib/gdbinit
popd
popenv
popenv
popenv

# task [096/158] /i686-pc-linux-gnu/toolchain/gdb/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [097/158] /i686-pc-linux-gnu/toolchain/gdb/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make install prefix=/scratch/macro/mips-sde-4.2/install exec_prefix=/scratch/macro/mips-sde-4.2/install libdir=/scratch/macro/mips-sde-4.2/install/lib htmldir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/man datadir=/scratch/macro/mips-sde-4.2/install/share
popd
popenv
popenv
popenv

# task [098/158] /i686-pc-linux-gnu/toolchain/gdb/0/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
popenv
popenv
popenv

# task [099/158] /i686-pc-linux-gnu/getting_started/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/getting_started-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu
copy_dir_clean /scratch/macro/mips-sde-4.2/src/getting-started-stable /scratch/macro/mips-sde-4.2/obj/getting_started-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/getting_started-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu
touch /scratch/macro/mips-sde-4.2/obj/getting_started-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu/.gnu-stamp
cat > /scratch/macro/mips-sde-4.2/obj/getting_started-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu/4.2-mips-sde-elf-lite-libs.xml <<'EOF0'
<!DOCTYPE getting-started SYSTEM "getting-started.dtd">
<!-- automatically generated, do not edit -->
<section id="sec-multilibs">
  <title>Library Configurations</title>
  <xi:include href="library-intro.xml" xpointer="xpointer(*/*)"/>
  <section>
    <title>Included Libraries</title>
    <para>
      The following library configurations are available in
      &csl_prod; for &csl_target_name;.
    </para>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry>default</entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>./</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32, mips16</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mips16</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>mips16/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32, fp64</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mfp64</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>fp64/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Soft-Float, O32</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-msoft-float</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>sof/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - No-Float, O32</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mno-float</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>nof/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32, mips16, fp64</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mips16 -mfp64</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>mips16/fp64/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32, mips16, Soft-Float</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mips16 -msoft-float</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>mips16/sof/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32, mips16, No-Float</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mips16 -mno-float</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>mips16/nof/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32, mips16, code-readable=no</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mips16 -mcode-readable=no</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>mips16/spram/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32, mips16, fp64, code-readable=no</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mips16 -mfp64 -mcode-readable=no</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>mips16/fp64/spram/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32, mips16, Soft-Float, code-readable=no</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mips16 -msoft-float -mcode-readable=no</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>mips16/sof/spram/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Big-Endian, O32, mips16, No-Float, code-readable=no</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mips16 -mno-float -mcode-readable=no</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>mips16/nof/spram/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, mips16</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mips16</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/mips16/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, fp64</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mfp64</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/fp64/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, Soft-Float</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -msoft-float</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/sof/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, No-Float</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mno-float</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/nof/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, mips16, fp64</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mips16 -mfp64</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/mips16/fp64/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, mips16, Soft-Float</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mips16 -msoft-float</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/mips16/sof/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, mips16, No-Float</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mips16 -mno-float</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/mips16/nof/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, mips16, code-readable=no</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mips16 -mcode-readable=no</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/mips16/spram/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, mips16, fp64, code-readable=no</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mips16 -mfp64 -mcode-readable=no</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/mips16/fp64/spram/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, mips16, Soft-Float, code-readable=no</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mips16 -msoft-float -mcode-readable=no</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/mips16/sof/spram/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">MIPS32 revision 2 - Little-Endian, O32, mips16, No-Float, code-readable=no</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-EL -mips16 -mno-float -mcode-readable=no</option></entry>
	</row>
	<row>
	  <entry>Library subdirectory:</entry>
	  <entry><filename>el/mips16/nof/spram/</filename></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
    </section>
  <xi:include href="library-selection.xml"/>
</section>
EOF0
cat > /scratch/macro/mips-sde-4.2/obj/getting_started-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu/4.2-mips-sde-elf-lite.dtd <<'EOF0'
<!-- automatically generated, do not edit -->
<!ENTITY csl_multilib_sec "<xi:include href='/scratch/macro/mips-sde-4.2/obj/getting_started-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu/4.2-mips-sde-elf-lite-libs.xml'/>">
<!ENTITY csl_subpackage_sec "">
<!ENTITY csl_binutils_component_license "&csl_gpl3.0_license;">
<!ENTITY csl_binutils_component_version "2.18.50">
<!ENTITY csl_gcc_component_license "&csl_gpl3.0_license;">
<!ENTITY csl_gcc_component_version "4.2.3">
<!ENTITY csl_gdb_component_license "&csl_gpl3.0_license;">
<!ENTITY csl_gdb_component_version "6.7.50">
<!ENTITY csl_sde_component_license "&csl_bsd_license;">
<!ENTITY csl_sdemdi_component_license "&csl_bsd_license;">
<!ENTITY csl_make_component_license "&csl_gpl2.0_license;">
<!ENTITY csl_coreutils_component_license "&csl_gpl2.0_license;">
EOF0
popenv
popenv
popenv

# task [100/158] /i686-pc-linux-gnu/getting_started/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/getting_started-4.2-199-mips-sde-elf-i686-pc-linux-gnu
mkdir -p /scratch/macro/mips-sde-4.2/obj/getting_started-4.2-199-mips-sde-elf-i686-pc-linux-gnu
pushd /scratch/macro/mips-sde-4.2/obj/getting_started-4.2-199-mips-sde-elf-i686-pc-linux-gnu
/scratch/macro/mips-sde-4.2/obj/getting_started-src-4.2-199-mips-sde-elf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/opt/codesourcery --host=i686-pc-linux-gnu --disable-nls --with-release-config=4.2-mips-sde-elf-lite '--with-components=binutils gcc gdb getting_started installanywhere ph eembc dhrystone sde sdemdi branding contents comparison csl_tests dejagnu_boards scripts xfails portal harness libiconv expat csl_docbook make coreutils qmtest_ph no-mingw no-w32api no-alf no-argp no-arm_stub no-atlas_install no-board_support no-ccs no-cctools no-cfpe_stub no-cloog no-cml no-com_codesourcery_util no-compiler_wrapper no-cs3 no-csldoc no-cxxabi no-cygwin_wrapper no-dinkum no-dtc no-eclipse no-eclipse_cdt no-eclipse_plugin no-eglibc no-eglibc_configs no-elf2flt no-elfutils no-fbench no-gdil no-glibc no-glibc_linuxthreads no-glibc_localedef no-glibc_ports no-gmp no-harness_test no-ide no-libcsftdi no-libelf no-libftdi no-libpng no-libsdl no-libunwind no-libusb no-libusb_win32 no-license no-linux no-mips_toolchain_manual no-mklibs no-mpatrol no-mpc no-mpfr no-msvcrt no-ncurses no-newlib no-ocdremote no-omf2elf no-openposix no-osprey no-ph_old no-plex_skel no-ppl no-prelink no-python no-python_macosx no-python_win32 no-qemu no-redboot no-rpm no-sgxx_demos no-simdmath no-spec2000 no-spec2000_configs no-srpm no-stellarisware no-stm32_generate_sgxx no-stm32_stdperiph_lib no-stm32_usb_fs_device_lib no-svp_docs no-sysroot_utils no-trace_processor no-uclibc no-uclibc_configs no-vpp_binary no-vpp_fftw no-vpp_source no-windows_script_wrapper no-zlib' '--with-features=gdbsimulator tarball public elf' '--with-hosts=i686-pc-linux-gnu i686-mingw32' '--with-host_os-name=IA32 GNU/Linux' --with-target-arch-name=MIPS --with-target-os-name=ELF --with-intermediate-dir=/scratch/macro/mips-sde-4.2/obj/getting_started-4.2-199-mips-sde-elf --with-csl-docbook=/scratch/macro/mips-sde-4.2/src/csl-docbook-stable --with-version-string=4.2-199 '--with-pkgversion=Sourcery G++ Lite 4.2-199' '--with-brand=Sourcery G++ Lite' '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog' --with-license=lite
popd
popenv
popenv
popenv

# task [101/158] /i686-pc-linux-gnu/getting_started/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/getting_started-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [102/158] /i686-pc-linux-gnu/getting_started/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/getting_started-4.2-199-mips-sde-elf-i686-pc-linux-gnu
make install prefix=/scratch/macro/mips-sde-4.2/install exec_prefix=/scratch/macro/mips-sde-4.2/install libdir=/scratch/macro/mips-sde-4.2/install/lib htmldir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/man datadir=/scratch/macro/mips-sde-4.2/install/share docdir=/scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf
popd
popenv
popenv
popenv

# task [103/158] /i686-pc-linux-gnu/csl_docbook
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
cp /scratch/macro/mips-sde-4.2/src/csl-docbook-stable/css/cs.css /scratch/macro/mips-sde-4.2/install/share/doc/mips-mips-sde-elf/html
popenv

# task [104/158] /i686-pc-linux-gnu/finalize_libc_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
popenv

# task [105/158] /i686-pc-linux-gnu/pretidy_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/install
rm ./lib/libiberty.a
popd
popenv

# task [106/158] /i686-pc-linux-gnu/remove_libtool_archives
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
find /scratch/macro/mips-sde-4.2/install -name '*.la' -exec rm '{}' ';'
popenv

# task [107/158] /i686-pc-linux-gnu/remove_copied_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
popenv

# task [108/158] /i686-pc-linux-gnu/remove_fixed_headers
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
pushd /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/include-fixed
popd
popenv

# task [109/158] /i686-pc-linux-gnu/add_tooldir_readme
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
cat > /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/README.txt <<'EOF0'
The executables in this directory are for internal use by the compiler
and may not operate correctly when used directly.  This directory
should not be placed on your PATH.  Instead, you should use the
executables in ../../bin/ and place that directory on your PATH.
EOF0
popenv

# task [110/158] /i686-pc-linux-gnu/strip_host_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-addr2line
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-ar
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-as
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-c++
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-c++filt
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-conv
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-cpp
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-g++
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-gcc
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-gcc-4.2.3
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-gcov
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-gdb
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-gdbtui
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-gprof
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-ld
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-nm
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-objcopy
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-objdump
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-ranlib
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-readelf
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-run
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-size
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-strings
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/bin/mips-sde-elf-strip
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/ar
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/as
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/c++
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/g++
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/gcc
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/ld
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/nm
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/objcopy
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/objdump
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/ranlib
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/mips-sde-elf/bin/strip
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/libexec/gcc/mips-sde-elf/4.2.3/cc1
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/libexec/gcc/mips-sde-elf/4.2.3/collect2
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/libexec/gcc/mips-sde-elf/4.2.3/install-tools/fixincl
/usr/local/tools/gcc-3.4.0/bin/i686-pc-linux-gnu-strip /scratch/macro/mips-sde-4.2/install/libexec/gcc/mips-sde-elf/4.2.3/cc1plus
popenv

# task [111/158] /i686-pc-linux-gnu/strip_target_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/spram/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/fp64/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/spram/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/nof/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/spram/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/sof/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/spram/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/mips16/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/fp64/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/nof/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/spram/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/fp64/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/spram/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/nof/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/spram/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/sof/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/spram/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/mips16/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/fp64/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/nof/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/sof/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/el/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/libc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/libm.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/libe.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/libsupc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/libmdi.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/sof/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/crt0.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/mips-sde-elf/lib/libstdc++.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/spram/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/spram/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/spram/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/spram/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/spram/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/spram/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/fp64/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/spram/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/spram/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/spram/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/spram/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/spram/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/spram/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/nof/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/spram/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/spram/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/spram/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/spram/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/spram/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/spram/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/sof/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/spram/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/spram/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/spram/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/spram/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/spram/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/spram/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/mips16/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/fp64/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/fp64/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/fp64/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/fp64/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/fp64/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/fp64/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/nof/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/nof/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/nof/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/nof/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/nof/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/nof/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/spram/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/spram/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/spram/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/spram/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/spram/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/spram/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/fp64/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/spram/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/spram/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/spram/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/spram/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/spram/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/spram/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/nof/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/spram/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/spram/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/spram/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/spram/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/spram/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/spram/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/sof/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/spram/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/spram/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/spram/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/spram/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/spram/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/spram/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/mips16/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/fp64/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/fp64/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/fp64/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/fp64/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/fp64/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/fp64/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/nof/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/nof/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/nof/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/nof/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/nof/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/nof/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/sof/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/sof/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/sof/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/sof/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/sof/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/sof/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/el/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/sof/crtend.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/sof/crtn.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/sof/libgcc.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/sof/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/sof/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/sof/libgcov.a || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/crti.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/crtbegin.o || true
mips-sde-elf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/macro/mips-sde-4.2/install/lib/gcc/mips-sde-elf/4.2.3/libgcov.a || true
popenv

# task [112/158] /i686-pc-linux-gnu/package_tbz2
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
rm -f /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf-i686-pc-linux-gnu.tar.bz2
pushd /scratch/macro/mips-sde-4.2/obj
rm -f mips-4.2
ln -s /scratch/macro/mips-sde-4.2/install mips-4.2
tar cjf /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf-i686-pc-linux-gnu.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 mips-4.2/bin mips-4.2/lib mips-4.2/libexec mips-4.2/mips-sde-elf mips-4.2/share
rm -f mips-4.2
popd
popenv

# task [113/158] /i686-pc-linux-gnu/package_installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/install/bin
/scratch/macro/mips-sde-4.2/src/scripts-trunk/gnu-installanywhere -i /scratch/macro/mips-sde-4.2/install -l /scratch/macro/mips-sde-4.2/logs -o /scratch/macro/mips-sde-4.2/obj -p /scratch/macro/mips-sde-4.2/pkg -s /scratch/macro/mips-sde-4.2/src -T /scratch/macro/mips-sde-4.2/testlogs -h i686-pc-linux-gnu -f /scratch/macro/mips-sde-4.2/obj/getting_started-4.2-199-mips-sde-elf/license.html sgxx/2008q1/mips-sde-elf-lite.cfg
popenv

# task [114/158] /i686-mingw32/host_cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
popenv

# task [115/158] /i686-mingw32/host_unpack
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
rm -rf /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32
mkdir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32
pushd /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32
ln -s . mips-4.2
tar xf /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf-i686-pc-linux-gnu.tar.bz2 --bzip2
rm mips-4.2
popd
popenv

# task [116/158] /i686-mingw32/libiconv/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/libiconv-4.2-199-mips-sde-elf-i686-mingw32
mkdir -p /scratch/macro/mips-sde-4.2/obj/libiconv-4.2-199-mips-sde-elf-i686-mingw32
pushd /scratch/macro/mips-sde-4.2/obj/libiconv-4.2-199-mips-sde-elf-i686-mingw32
/scratch/macro/mips-sde-4.2/src/libiconv-1.11/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/scratch/macro/mips-sde-4.2/obj/host-libs-4.2-199-mips-sde-elf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls
popd
popenv
popenv
popenv

# task [117/158] /i686-mingw32/libiconv/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/libiconv-4.2-199-mips-sde-elf-i686-mingw32
make -j1
popd
popenv
popenv
popenv

# task [118/158] /i686-mingw32/libiconv/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/libiconv-4.2-199-mips-sde-elf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [119/158] /i686-mingw32/make/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/make-src-4.2-199-mips-sde-elf-i686-mingw32
copy_dir_clean /scratch/macro/mips-sde-4.2/src/make-3.81 /scratch/macro/mips-sde-4.2/obj/make-src-4.2-199-mips-sde-elf-i686-mingw32
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/make-src-4.2-199-mips-sde-elf-i686-mingw32
touch /scratch/macro/mips-sde-4.2/obj/make-src-4.2-199-mips-sde-elf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [120/158] /i686-mingw32/make/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/make-4.2-199-mips-sde-elf-i686-mingw32
mkdir -p /scratch/macro/mips-sde-4.2/obj/make-4.2-199-mips-sde-elf-i686-mingw32
pushd /scratch/macro/mips-sde-4.2/obj/make-4.2-199-mips-sde-elf-i686-mingw32
/scratch/macro/mips-sde-4.2/obj/make-src-4.2-199-mips-sde-elf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 4.2-199' --disable-nls --program-prefix=cs-
popd
popenv
popenv
popenv

# task [121/158] /i686-mingw32/make/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/make-4.2-199-mips-sde-elf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [122/158] /i686-mingw32/make/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/make-4.2-199-mips-sde-elf-i686-mingw32
make install prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 exec_prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 libdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/lib htmldir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/man datadir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [123/158] /i686-mingw32/coreutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/coreutils-src-4.2-199-mips-sde-elf-i686-mingw32
copy_dir_clean /scratch/macro/mips-sde-4.2/src/coreutils-5.94 /scratch/macro/mips-sde-4.2/obj/coreutils-src-4.2-199-mips-sde-elf-i686-mingw32
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/coreutils-src-4.2-199-mips-sde-elf-i686-mingw32
touch /scratch/macro/mips-sde-4.2/obj/coreutils-src-4.2-199-mips-sde-elf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [124/158] /i686-mingw32/coreutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/coreutils-4.2-199-mips-sde-elf-i686-mingw32
mkdir -p /scratch/macro/mips-sde-4.2/obj/coreutils-4.2-199-mips-sde-elf-i686-mingw32
pushd /scratch/macro/mips-sde-4.2/obj/coreutils-4.2-199-mips-sde-elf-i686-mingw32
/scratch/macro/mips-sde-4.2/obj/coreutils-src-4.2-199-mips-sde-elf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 4.2-199' --disable-nls --program-prefix=cs-
popd
popenv
popenv
popenv

# task [125/158] /i686-mingw32/coreutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/coreutils-4.2-199-mips-sde-elf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [126/158] /i686-mingw32/coreutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/coreutils-4.2-199-mips-sde-elf-i686-mingw32
make install prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 exec_prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 libdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/lib htmldir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/man datadir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [127/158] /i686-mingw32/toolchain/binutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-mingw32
copy_dir_clean /scratch/macro/mips-sde-4.2/src/binutils-mips /scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-mingw32
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-mingw32
touch /scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [128/158] /i686-mingw32/toolchain/binutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-mingw32
mkdir -p /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-mingw32
pushd /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-mingw32
/scratch/macro/mips-sde-4.2/obj/binutils-src-4.2-199-mips-sde-elf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 4.2-199' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --with-sysroot=/opt/codesourcery/mips-sde-elf --enable-poison-system-directories
popd
popenv
popenv
popenv

# task [129/158] /i686-mingw32/toolchain/binutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [130/158] /i686-mingw32/toolchain/binutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-mingw32
make install prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 exec_prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 libdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/lib htmldir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/man datadir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [131/158] /i686-mingw32/toolchain/binutils/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/install/host-i686-mingw32
rm lib/charset.alias
rm ./lib/libiberty.a
rmdir ./lib
popd
copy_dir_clean /scratch/macro/mips-sde-4.2/src/binutils-mips/include /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-mingw32/usr/include
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-mingw32/usr/include
mkdir -p /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-mingw32/usr/lib
cp /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-mingw32/libiberty/libiberty.a /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-mingw32/usr/lib
cp /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-mingw32/bfd/.libs/libbfd.a /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-mingw32/usr/lib
cp /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-mingw32/bfd/bfd.h /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-mingw32/usr/include
cp /scratch/macro/mips-sde-4.2/src/binutils-mips/bfd/elf-bfd.h /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-mingw32/usr/include
cp /scratch/macro/mips-sde-4.2/obj/binutils-4.2-199-mips-sde-elf-i686-mingw32/opcodes/.libs/libopcodes.a /scratch/macro/mips-sde-4.2/obj/host-binutils-4.2-199-mips-sde-elf-i686-mingw32/usr/lib
popenv
popenv
popenv

# task [132/158] /i686-mingw32/toolchain/copy_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/share/doc/mips-mips-sde-elf/html /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/html
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/share/doc/mips-mips-sde-elf/pdf /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/pdf
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/share/doc/mips-mips-sde-elf/info /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/info
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/share/doc/mips-mips-sde-elf/man /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/man
cp /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/share/doc/mips-mips-sde-elf/LICENSE.txt /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/mips-sde-elf/lib /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/lib
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/mips-sde-elf/include /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/include
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/mips-sde-elf/include/c++ /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/include/c++
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/lib/gcc/mips-sde-elf /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/lib/gcc/mips-sde-elf
popenv

# task [133/158] /i686-mingw32/toolchain/gcc_final/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
pushenvvar CC_FOR_TARGET mips-sde-elf-gcc
pushenvvar GCC_FOR_TARGET mips-sde-elf-gcc
pushenvvar CXX_FOR_TARGET mips-sde-elf-g++
rm -f /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/usr
ln -s . /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/usr
rm -rf /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-mingw32
mkdir -p /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-mingw32
pushd /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-mingw32
/scratch/macro/mips-sde-4.2/src/gcc-4.2/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=mips-sde-elf --enable-threads --disable-libmudflap --disable-libssp --disable-libstdcxx-pch --with-arch=mips32r2 --enable-sgxx-sde-multilibs --with-gnu-as --with-gnu-ld --enable-languages=c,c++ --disable-shared --disable-lto '--with-pkgversion=Sourcery G++ Lite 4.2-199' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --prefix=/opt/codesourcery --with-headers=yes --with-sysroot=/opt/codesourcery/mips-sde-elf --with-build-sysroot=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf --with-libiconv-prefix=/scratch/macro/mips-sde-4.2/obj/host-libs-4.2-199-mips-sde-elf-i686-mingw32/usr --disable-libgomp --enable-poison-system-directories --with-build-time-tools=/scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/mips-sde-elf/bin --with-build-time-tools=/scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/mips-sde-elf/bin
popd
popenv
popenv

# task [134/158] /i686-mingw32/toolchain/gcc_final/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
pushenvvar CC_FOR_TARGET mips-sde-elf-gcc
pushenvvar GCC_FOR_TARGET mips-sde-elf-gcc
pushenvvar CXX_FOR_TARGET mips-sde-elf-g++
rm -f /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/usr
ln -s . /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/usr
pushd /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-mingw32
make -j4 LDFLAGS_FOR_TARGET=--sysroot=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf CPPFLAGS_FOR_TARGET=--sysroot=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf build_tooldir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf all-gcc
popd
popenv
popenv

# task [135/158] /i686-mingw32/toolchain/gcc_final/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
pushenvvar CC_FOR_TARGET mips-sde-elf-gcc
pushenvvar GCC_FOR_TARGET mips-sde-elf-gcc
pushenvvar CXX_FOR_TARGET mips-sde-elf-g++
rm -f /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/usr
ln -s . /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/usr
pushd /scratch/macro/mips-sde-4.2/obj/gcc-4.2-199-mips-sde-elf-i686-mingw32
make prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 exec_prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 libdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/lib htmldir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/man install-gcc
popd
popenv
popenv

# task [136/158] /i686-mingw32/toolchain/gcc_final/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET mips-sde-elf-ar
pushenvvar NM_FOR_TARGET mips-sde-elf-nm
pushenvvar OBJDUMP_FOR_TARET mips-sde-elf-objdump
pushenvvar STRIP_FOR_TARGET mips-sde-elf-strip
pushenvvar CC_FOR_TARGET mips-sde-elf-gcc
pushenvvar GCC_FOR_TARGET mips-sde-elf-gcc
pushenvvar CXX_FOR_TARGET mips-sde-elf-g++
pushd /scratch/macro/mips-sde-4.2/install/host-i686-mingw32
rm bin/mips-sde-elf-gccbug
rmdir include
popd
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/lib/gcc/mips-sde-elf /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/lib/gcc/mips-sde-elf
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/mips-sde-elf/lib /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/lib
copy_dir /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/mips-sde-elf/include/c++ /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/include/c++
rm -f /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/usr
popenv
popenv

# task [137/158] /i686-mingw32/toolchain/expat/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-mingw32
mkdir -p /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-mingw32
pushd /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-mingw32
/scratch/macro/mips-sde-4.2/src/expat-mirror/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/scratch/macro/mips-sde-4.2/obj/host-libs-4.2-199-mips-sde-elf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls
popd
popenv
popenv
popenv

# task [138/158] /i686-mingw32/toolchain/expat/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [139/158] /i686-mingw32/toolchain/expat/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/expat-4.2-199-mips-sde-elf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [140/158] /i686-mingw32/toolchain/gdb/0/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-mingw32
copy_dir_clean /scratch/macro/mips-sde-4.2/src/gdb-mips /scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-mingw32
chmod -R u+w /scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-mingw32
touch /scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [141/158] /i686-mingw32/toolchain/gdb/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-mingw32
mkdir -p /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-mingw32
pushd /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-mingw32
/scratch/macro/mips-sde-4.2/obj/gdb-src-4.2-199-mips-sde-elf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=mips-sde-elf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 4.2-199' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --with-libexpat-prefix=/scratch/macro/mips-sde-4.2/obj/host-libs-4.2-199-mips-sde-elf-i686-mingw32/usr --with-system-gdbinit=/opt/codesourcery/i686-mingw32/mips-sde-elf/lib/gdbinit
popd
popenv
popenv
popenv

# task [142/158] /i686-mingw32/toolchain/gdb/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [143/158] /i686-mingw32/toolchain/gdb/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/macro/mips-sde-4.2/obj/gdb-4.2-199-mips-sde-elf-i686-mingw32
make install prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 exec_prefix=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32 libdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/lib htmldir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/html pdfdir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/pdf infodir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/info mandir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share/doc/mips-mips-sde-elf/man datadir=/scratch/macro/mips-sde-4.2/install/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [144/158] /i686-mingw32/toolchain/gdb/0/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushenv
pushenv
popenv
popenv
popenv

# task [145/158] /i686-mingw32/pretidy_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushd /scratch/macro/mips-sde-4.2/install/host-i686-mingw32
rm ./lib/libiberty.a
popd
popenv

# task [146/158] /i686-mingw32/remove_libtool_archives
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
find /scratch/macro/mips-sde-4.2/install/host-i686-mingw32 -name '*.la' -exec rm '{}' ';'
popenv

# task [147/158] /i686-mingw32/remove_copied_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
popenv

# task [148/158] /i686-mingw32/remove_fixed_headers
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
pushd /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/lib/gcc/mips-sde-elf/4.2.3/include-fixed
popd
popenv

# task [149/158] /i686-mingw32/add_tooldir_readme
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
cat > /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/README.txt <<'EOF0'
The executables in this directory are for internal use by the compiler
and may not operate correctly when used directly.  This directory
should not be placed on your PATH.  Instead, you should use the
executables in ../../bin/ and place that directory on your PATH.
EOF0
popenv

# task [150/158] /i686-mingw32/strip_host_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/cs-make.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/cs-rm.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-addr2line.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-ar.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-as.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-c++.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-c++filt.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-conv.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-cpp.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-g++.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-gcc-4.2.3.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-gcc.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-gcov.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-gdb.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-gprof.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-ld.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-nm.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-objcopy.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-objdump.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-ranlib.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-readelf.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-run.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-size.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-strings.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/bin/mips-sde-elf-strip.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/ar.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/as.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/c++.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/g++.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/gcc.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/ld.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/nm.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/objcopy.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/objdump.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/ranlib.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/bin/strip.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/libexec/gcc/mips-sde-elf/4.2.3/cc1.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/libexec/gcc/mips-sde-elf/4.2.3/collect2.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/libexec/gcc/mips-sde-elf/4.2.3/install-tools/fixincl.exe
i686-mingw32-strip /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/libexec/gcc/mips-sde-elf/4.2.3/cc1plus.exe
popenv

# task [151/158] /i686-mingw32/package_tbz2
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
rm -f /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf-i686-mingw32.tar.bz2
pushd /scratch/macro/mips-sde-4.2/install/host-i686-mingw32
rm ./mips-sde-elf/include/machine
cp -al /scratch/macro/mips-sde-4.2/install/host-i686-mingw32/mips-sde-elf/include/mips ./mips-sde-elf/include/machine
popd
pushd /scratch/macro/mips-sde-4.2/obj
rm -f mips-4.2
ln -s /scratch/macro/mips-sde-4.2/install/host-i686-mingw32 mips-4.2
tar cjf /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf-i686-mingw32.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 mips-4.2/bin mips-4.2/lib mips-4.2/libexec mips-4.2/mips-sde-elf mips-4.2/share
rm -f mips-4.2
popd
popenv

# task [152/158] /i686-mingw32/package_installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/macro/mips-sde-4.2/obj/tools-i686-pc-linux-gnu-4.2-199-mips-sde-elf-i686-mingw32/bin
/scratch/macro/mips-sde-4.2/src/scripts-trunk/gnu-installanywhere -i /scratch/macro/mips-sde-4.2/install/host-i686-mingw32 -l /scratch/macro/mips-sde-4.2/logs -o /scratch/macro/mips-sde-4.2/obj -p /scratch/macro/mips-sde-4.2/pkg -s /scratch/macro/mips-sde-4.2/src -T /scratch/macro/mips-sde-4.2/testlogs -h i686-mingw32 -f /scratch/macro/mips-sde-4.2/obj/getting_started-4.2-199-mips-sde-elf/license.html sgxx/2008q1/mips-sde-elf-lite.cfg
popenv

# task [153/158] /fini/build_summary
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
cat > /scratch/macro/mips-sde-4.2/obj/gnu-4.2-199-mips-sde-elf.txt <<'EOF0'
Version Information
===================

Version:           4.2-199
Host spec(s):      i686-pc-linux-gnu i686-mingw32
Target:            mips-sde-elf

Build Information
=================

Build date:             20091119
Build machine:          henry2
Build operating system: lenny/sid
Build uname:            Linux henry2 2.6.24-19-server #1 SMP Wed Aug 20 18:43:06 UTC 2008 x86_64 unknown unknown GNU/Linux
Build user:             macro

EOF0
popenv

# task [154/158] /fini/extras_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.extras
pushd /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf
tar cjf /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf.extras.tar.bz2 --owner=0 --group=0 mips-4.2-199-mips-sde-elf.extras
popd
popenv

# task [155/158] /fini/backups_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf.backup
pushd /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf
tar cjf /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf.backup.tar.bz2 --owner=0 --group=0 mips-4.2-199-mips-sde-elf.backup
popd
popenv

# task [156/158] /fini/sources_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
cp /scratch/macro/mips-sde-4.2/obj/gnu-4.2-199-mips-sde-elf.txt /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
cp /scratch/macro/mips-sde-4.2/logs/mips-4.2-199-mips-sde-elf.sh /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf/mips-4.2-199-mips-sde-elf
pushd /scratch/macro/mips-sde-4.2/obj/pkg-4.2-199-mips-sde-elf
tar cjf /scratch/macro/mips-sde-4.2/pkg/mips-4.2-199-mips-sde-elf.src.tar.bz2 --owner=0 --group=0 mips-4.2-199-mips-sde-elf
popd
/scratch/macro/mips-sde-4.2/src/scripts-trunk/gnu-test -i /scratch/macro/mips-sde-4.2/install -l /scratch/macro/mips-sde-4.2/logs -o /scratch/macro/mips-sde-4.2/obj -p /scratch/macro/mips-sde-4.2/pkg -s /scratch/macro/mips-sde-4.2/src -T /scratch/macro/mips-sde-4.2/testlogs -T /scratch/macro/mips-sde-4.2/obj/testlogs-4.2-199-mips-sde-elf sgxx/2008q1/mips-sde-elf-lite.cfg
copy_dir /scratch/macro/mips-sde-4.2/obj/testlogs-4.2-199-mips-sde-elf /scratch/macro/mips-sde-4.2/testlogs
/scratch/macro/mips-sde-4.2/src/scripts-trunk/gnu-test-package -i /scratch/macro/mips-sde-4.2/install -l /scratch/macro/mips-sde-4.2/logs -o /scratch/macro/mips-sde-4.2/obj -p /scratch/macro/mips-sde-4.2/pkg -s /scratch/macro/mips-sde-4.2/src -T /scratch/macro/mips-sde-4.2/testlogs -T /scratch/macro/mips-sde-4.2/obj/testlogs-4.2-199-mips-sde-elf sgxx/2008q1/mips-sde-elf-lite.cfg
